==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/PMScheduleandMaintenancePatternDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDGROUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETDUEVALUES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATEREFERENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVATEMPS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "departmentid",
    "locationid",
    "costcodeid",
    "assignedto",
    "schedgroup",
    "setduevalues",
    "duedatereference",
    "activatemps"
})
@XmlRootElement(name = "PMScheduleandMaintenancePatternDetails")
public class PMScheduleandMaintenancePatternDetails {

    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "SCHEDGROUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String schedgroup;
    @XmlElement(name = "SETDUEVALUES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String setduevalues;
    @XmlElement(name = "DUEDATEREFERENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME duedatereference;
    @XmlElement(name = "ACTIVATEMPS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String activatemps;

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété costcodeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Définit la valeur de la propriété costcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété schedgroup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCHEDGROUP() {
        return schedgroup;
    }

    /**
     * Définit la valeur de la propriété schedgroup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCHEDGROUP(String value) {
        this.schedgroup = value;
    }

    /**
     * Obtient la valeur de la propriété setduevalues.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSETDUEVALUES() {
        return setduevalues;
    }

    /**
     * Définit la valeur de la propriété setduevalues.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSETDUEVALUES(String value) {
        this.setduevalues = value;
    }

    /**
     * Obtient la valeur de la propriété duedatereference.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATEREFERENCE() {
        return duedatereference;
    }

    /**
     * Définit la valeur de la propriété duedatereference.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATEREFERENCE(DATETIME value) {
        this.duedatereference = value;
    }

    /**
     * Obtient la valeur de la propriété activatemps.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVATEMPS() {
        return activatemps;
    }

    /**
     * Définit la valeur de la propriété activatemps.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVATEMPS(String value) {
        this.activatemps = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/PMScheduleandMaintenancePatternDetails.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDGROUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETDUEVALUES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATEREFERENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVATEMPS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "departmentid",
    "locationid",
    "costcodeid",
    "assignedto",
    "schedgroup",
    "setduevalues",
    "duedatereference",
    "activatemps"
})
@XmlRootElement(name = "PMScheduleandMaintenancePatternDetails")
public class PMScheduleandMaintenancePatternDetails {

    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "SCHEDGROUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String schedgroup;
    @XmlElement(name = "SETDUEVALUES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String setduevalues;
    @XmlElement(name = "DUEDATEREFERENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME duedatereference;
    @XmlElement(name = "ACTIVATEMPS", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String activatemps;

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the costcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Sets the value of the costcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the schedgroup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCHEDGROUP() {
        return schedgroup;
    }

    /**
     * Sets the value of the schedgroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCHEDGROUP(String value) {
        this.schedgroup = value;
    }

    /**
     * Gets the value of the setduevalues property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSETDUEVALUES() {
        return setduevalues;
    }

    /**
     * Sets the value of the setduevalues property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSETDUEVALUES(String value) {
        this.setduevalues = value;
    }

    /**
     * Gets the value of the duedatereference property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATEREFERENCE() {
        return duedatereference;
    }

    /**
     * Sets the value of the duedatereference property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATEREFERENCE(DATETIME value) {
        this.duedatereference = value;
    }

    /**
     * Gets the value of the activatemps property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVATEMPS() {
        return activatemps;
    }

    /**
     * Sets the value of the activatemps property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVATEMPS(String value) {
        this.activatemps = value;
    }

}
